==> tine20-humanresources_2019.12.5.tar.bz2: HumanResources/js/HumanResources-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Nie masz dostępu do działu HR"

, "Wage types"
: ""

, "Free time types"
: ""

, "Working time scheme, Working time schemes"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book as vacation"
: ""

, "Sickness"
: "Chorobowe"

, "Sickness Days"
: ""

, "Vacation"
: "Urlop"

, "Vacation Days"
: "Dni urlopu"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""
 ,""
 ,""

]
, "Template"
: ""

, "Individual"
: ""

, "Shared"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""
 ,""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Opis"

, "Employee, Employees"
: [
  "Pracownik"
 ,"Pracownicy"
 ,"Pracownicy"
 ,"Pracownicy"

]
, "Calculate all Reports"
: ""

, "Recalculate"
: ""

, "Cancel"
: "Anuluj"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Kalendarz"

, "Calendars"
: "Kalendarze"

, "Vacation expires"
: ""

, "Book remaining vacation"
: ""

, "Year"
: ""

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  "Centrum kosztów"
 ,"Centra kosztów"
 ,"Centra kosztów"
 ,"Centra kosztów"

]
, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,"Centrum kosztów"
 ,"Centrum kosztów"

]
, "Startdate"
: "Data rozpoczęcia"

, "Contract, Contracts"
: [
  "Umowa"
 ,"Umowy"
 ,"Umowy"
 ,"Umowy"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Working Time Rules"
: ""

, "Start Date"
: "Data rozpoczęcia"

, "End Date"
: "Data zakończenia"

, "Feast Calendar"
: "Kalendarz świąt"

, "Vacation days of one calendar year"
: ""

, "Working Time Schema"
: ""

, "Working Hours per week"
: "Godziny pracy w tygodniu"

, "Mon."
: "Pon."

, "Tue."
: "Wt."

, "Wed."
: "Śr."

, "Thu."
: "Czw."

, "Fri."
: "Pt."

, "Sat."
: "Sob."

, "Sun."
: "Niedz."

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Status"
: "Status"

, "Remaining"
: ""

, "Select Days"
: "Wybierz dni"

, "Enter description"
: "Wprowadź opis"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Oddział"

, "Health Insurance"
: "Ubezpieczenie zdrowotne"

, "Apply contact data on form"
: "Dodaj dane kontaktowe do formularza"

, "Salutation"
: "Forma grzecznościowa"

, "Personal Information"
: "Informacje osobiste"

, "Country"
: "Kraj"

, "Birthday"
: "Urodziny"

, "Internal Information"
: "Informacje wewnętrzne"

, "Banking Information"
: "Informacje bankowe"

, "Type"
: "Typ"

, "Template (individual working time schemas are created for each contract)"
: ""

, "Shared (this working time schemas can be shared among contracts)"
: ""

, "Days"
: ""

, "Expiration date"
: ""

, "WK"
: "TK"

, "Loading calendar data..."
: "Ładowanie danych kalendarza..."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: "Usprawiedliwiona"

, "Unexcused"
: "Nieusprawiedliwiona"

, "Currently employed"
: "Obecnie zatrudniony"

, "Employees which are currently employed"
: "Zatrudnieni pracownicy"

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Default wage type"
: ""

, "Salary"
: ""

, "Business trip"
: ""

, "Sunday bonus"
: ""

, "Feast day"
: ""

, "Feast day bonus"
: ""

, "Overtime"
: ""

, "Overtime bonus"
: ""

, "Late shift bonus"
: ""

, "Night bonus"
: ""

, "Break"
: ""

, "Stand by"
: ""

, "Unpaid"
: ""

, "[S] Sickness"
: ""

, "[D] Visit doctor"
: ""

, "[V] Vacation"
: ""

, "[BT] Business trip"
: ""

, "[FT] Flex time"
: ""

, "[BK] Break"
: ""

, "[T] Training"
: ""

, "Freetime Type"
: "Typ wolnego"

, "Possible free time definitions"
: "Możliwe definicje wolnego"

, "Vacation Status"
: "Status urlopu"

, "Possible vacation status definitions"
: "Możliwe definicje statusu wolnego"

, "Requested"
: "Na żądanie"

, "In process"
: "W opracowaniu"

, "Accepted"
: "Zaakceptowany"

, "Declined"
: "Odrzucony"

, "Sickness Status"
: "Status chorobowego"

, "Possible sickness status definitions"
: "Możliwe definicje statusu chorobowego"

, "Default Feast Calendar"
: "Domyślny kalendarz świąt"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Tutaj możesz zdefiniować domyślny kalendarz świąt używany do ustawiania dni świątecznych i innych wolnych dni w miejscach wyboru daty"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "No valid contract for this date"
: ""

, "unexpected error: "
: ""

, "daily wt reports can't be created"
: ""

, "It is not allowed to update a cleared report"
: ""

, "monthly wt reports can't be created"
: ""

, "previous months need to be cleared first"
: ""

, "following months need to be uncleared first"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""
 ,""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Corrected Evaluation Start Time"
: ""

, "Corrected Evaluation End Time"
: ""

, "Target Working Time"
: ""

, "Target Working Time Correction"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Working Times"
: ""

, "Actual Working Time"
: ""

, "Working Time Correction"
: ""

, "Total Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Calculation Error"
: ""

, "Monthly Working Time Report, Monthly Working Time Reports"
: [
  ""
 ,""
 ,""
 ,""

]
, "Month"
: ""

, "Daily Working Time Reports"
: ""

, "Working Time Balance Previous Month"
: ""

, "Total Working Time Balance"
: ""

, "Wage type, Wage types"
: [
  ""
 ,""
 ,""
 ,""

]
, "Abbreviation"
: ""

, "Name"
: ""

, "System"
: ""

, "Factor (%)"
: ""

, "Additional Wage"
: ""

, "Quick search"
: ""

, "Extra free times"
: ""

, "Start time"
: ""

, "Break Time, Break Times"
: [
  ""
 ,""
 ,""
 ,""

]
, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
: ""

, "Time worked"
: ""

, "Break time"
: ""

, "Work Time Limit, Work Time Limits"
: [
  ""
 ,""
 ,""
 ,""

]
, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
: ""

, "Absence reason, Absence reasons"
: [
  ""
 ,""
 ,""
 ,""

]
, "Allow Booking"
: ""

, "Allow Planning"
: ""

, "Enable Freetime Timetracking"
: ""

, "Timeaccount"
: ""

, "Free Time, Free Times"
: [
  "Urlop"
 ,"Urlopy"
 ,"Urlopy"
 ,"Urlopy"

]
, "Account"
: "Konto"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: ""

, "Is employed"
: ""

, "Number"
: "Numer"

, "Transponder Id"
: ""

, "Germany"
: ""

, "Locality"
: "Miejscowość"

, "Postalcode"
: "Kod pocztowy"

, "Region"
: "Region"

, "Street"
: "Ulica"

, "Street 2"
: ""

, "E-Mail"
: "E-mail"

, "Telephone Number"
: "Numer telefonu stacjonarnego"

, "Cell Phone Number"
: "Numer telefonu komórkowego"

, "Title"
: "Tytuł naukowy"

, "Last Name"
: "Nazwisko"

, "First Name"
: "Imię"

, "Employee name"
: "Nazwa pracownika"

, "Account Holder"
: "Właściciel konta"

, "Account Number"
: "Numer konta"

, "Bank Name"
: "Nazwa banku"

, "Code Number"
: "Kod"

, "Employment begin"
: "Początek zatrudnienia"

, "Employment end"
: "Koniec zatrudnienia"

, "Supervisor"
: "Przełożony"

, "Profession"
: "Zawód"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Wolny dzień"
 ,"wolne dni"
 ,"wolne dni"
 ,"wolne dni"

]
, "No contract could be found."
: "Nie znaleziono umowy"

, "Please create a contract for this employee!"
: "Proszę utworzyć umowę dla niniejszego pracownika!"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "Edytuj prywatne dane pracownika"

, "Edit birthday, account data and other private information of employee records"
: "Edytuj urodziny, dane o koncie bankowym i inne, prywatne informacje pracownika"


, "Working time scheme"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Pracownik"

, "CostCenter"
: "Centrum kosztów"

, "Cost Center"
: ""

, "Contract"
: "Umowa"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Monthly Working Time Report"
: ""

, "Wage type"
: ""

, "Break Time"
: ""

, "Work Time Limit"
: ""

, "Absence reason"
: ""

, "Free Time"
: "Urlop"

, "Free Day"
: "Wolny dzień"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-humanresources_2020.08.8.tar.bz2: HumanResources/js/HumanResources-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of HumanResources **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "You do not have admin rights on HumanResources"
: "Nie masz dostępu do działu HR"

, "Working time model"
: ""

, "Book as vacation"
: ""

, "Sickness"
: "Chorobowe"

, "Sickness Days"
: ""

, "Vacation"
: "Urlop"

, "Vacation Days"
: "Dni urlopu"

, "There could not be found any {0}. Please try to change your filter-criteria or view-options."
: ""

, "Could not book as vacation"
: ""

, "The unexcused sickness days could not be booked as vacation. There are not enough days left!"
: ""

, "Human Resources, Human Resources"
: [
  ""
 ,""
 ,""
 ,""

]
, "Title"
: "Tytuł naukowy"

, "Work Start"
: ""

, "Work End"
: ""

, "Edit {0} for {1} - {2}"
: ""

, "Extra free time, Extra free times"
: [
  ""
 ,""
 ,""
 ,""

]
, "Summary"
: ""

, "Free Times"
: ""

, "Possible vaction days"
: ""

, "Remaining vaction days"
: ""

, "Taken vaction days"
: ""

, "Expired vaction days"
: ""

, "Rebooked vaction days"
: ""

, "Excused sickness days"
: ""

, "Unexcused sickness days"
: ""

, "Working Time"
: ""

, "Days to work"
: ""

, "Hours to work"
: ""

, "Days to work after vacation and sickness"
: ""

, "Hours to work after vacation and sickness"
: ""

, "Miscellaneous"
: ""

, "Description"
: "Opis"

, "Working time Model"
: ""

, "Work start"
: ""

, "not set"
: ""

, "Work end"
: ""

, "Working Hours per week"
: "Godziny pracy w tygodniu"

, "Mon."
: "Pon."

, "Tue."
: "Wt."

, "Wed."
: "Śr."

, "Thu."
: "Czw."

, "Fri."
: "Pt."

, "Sat."
: "Sob."

, "Sun."
: "Niedz."

, "Employee, Employees"
: [
  "Pracownik"
 ,"Pracownicy"
 ,"Pracownicy"
 ,"Pracownicy"

]
, "Cancel"
: "Anuluj"

, "OK"
: "OK"

, "Please use the following format: MM-DD"
: ""

, "Calendar"
: "Kalendarz"

, "Calendars"
: "Kalendarze"

, "Vacation expires"
: ""

, "Breaks"
: ""

, "Hours"
: ""

, "Break duration"
: ""

, "Book remaining vacation"
: ""

, "Year"
: ""

, "Please enter the year you want to create accounts for:"
: ""

, "Accounts have been created"
: ""

, "{0} accounts for the year {1} have been created successfully!"
: ""

, "Create new accounts"
: ""

, "Booking has been successfull!"
: ""

, "The remaining vacation days of the selected accounts have been booked successfully!"
: ""

, "CostCenter, CostCenters"
: [
  "Centrum kosztów"
 ,"Centra kosztów"
 ,"Centra kosztów"
 ,"Centra kosztów"

]
, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,"Centrum kosztów"
 ,"Centrum kosztów"

]
, "Startdate"
: "Data rozpoczęcia"

, "Contract, Contracts"
: [
  "Umowa"
 ,"Umowy"
 ,"Umowy"
 ,"Umowy"

]
, "Vacation in same period"
: ""

, "There are some vacation days matching the period of the contract you added. After saving this employee, changing the contract is not possible anymore."
: ""

, "Edit {0}"
: ""

, "Start Date"
: "Data rozpoczęcia"

, "End Date"
: "Data zakończenia"

, "Feast Calendar"
: "Kalendarz świąt"

, "Choose the template"
: "Wybierz szablon"

, "Vacation days of one calendar year"
: ""

, "Edit {0} \"{1}\""
: ""

, "Edit {0} for {1}"
: ""

, "Add {0} for {1}"
: ""

, "You have to select at least one day to save this sickness entry."
: ""

, "You have to select at least one day to save this vacation entry."
: ""

, "No day selected"
: ""

, "Personal account, Personal accounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Status"
: "Status"

, "Remaining"
: ""

, "Select Days"
: "Wybierz dni"

, "Enter description"
: "Wprowadź opis"

, "Account is disabled or deleted!"
: ""

, "Division"
: "Oddział"

, "Health Insurance"
: "Ubezpieczenie zdrowotne"

, "Apply contact data on form"
: "Dodaj dane kontaktowe do formularza"

, "Salutation"
: "Forma grzecznościowa"

, "Personal Information"
: "Informacje osobiste"

, "Country"
: "Kraj"

, "Birthday"
: "Urodziny"

, "Internal Information"
: "Informacje wewnętrzne"

, "Banking Information"
: "Informacje bankowe"

, "Days"
: ""

, "Type"
: "Typ"

, "Expiration date"
: ""

, "WK"
: "TK"

, "Loading calendar data..."
: "Ładowanie danych kalendarza..."

, "Year can not be changed"
: ""

, "You have already selected some dates from another year. Please create a new record to add dates from another year!"
: ""

, "No more vacation days"
: ""

, "The Employee has no more possible vacation days left for this year. Create a new vacation and use another personal account the vacation should be taken from."
: ""

, "Excused"
: "Usprawiedliwiona"

, "Unexcused"
: "Nieusprawiedliwiona"

, "Currently employed"
: "Obecnie zatrudniony"

, "Employees which are currently employed"
: "Zatrudnieni pracownicy"

, "All employees"
: ""

, "All available employees"
: ""

, "Payed"
: ""

, "Not payed"
: ""

, "Currently employed employees"
: ""

, "All accounts"
: ""

, "All available accounts"
: ""

, "Full-time 40 hours"
: ""

, "Full-time 37.5 hours"
: ""

, "Part-time 20 hours"
: ""

, "Freetime Type"
: "Typ wolnego"

, "Possible free time definitions"
: "Możliwe definicje wolnego"

, "Vacation Status"
: "Status urlopu"

, "Possible vacation status definitions"
: "Możliwe definicje statusu wolnego"

, "Requested"
: "Na żądanie"

, "In process"
: "W opracowaniu"

, "Accepted"
: "Zaakceptowany"

, "Declined"
: "Odrzucony"

, "Sickness Status"
: "Status chorobowego"

, "Possible sickness status definitions"
: "Możliwe definicje statusu chorobowego"

, "Default Feast Calendar"
: "Domyślny kalendarz świąt"

, "Here you can define the default feast calendar used to set feast days and other free days in datepicker"
: "Tutaj możesz zdefiniować domyślny kalendarz świąt używany do ustawiania dni świątecznych i innych wolnych dni w miejscach wyboru daty"

, "Enabled Features"
: ""

, "Enabled Features in HumanResources Application."
: ""

, "Calculate Daily Reports"
: ""

, "Activate to calculate daily reports with a nightly scheduler job"
: ""

, "Extra freetime type"
: ""

, "Possible extra free time definitions"
: ""

, "Here you can define the day, when the vacation days taken from last year expires, the format is MM-DD."
: ""

, "Report Templates Node ID"
: ""

, "Timetracker Timeaccount for Workingtime Tracking"
: ""

, "Daily Working Time Report, Daily Working Time Reports"
: [
  ""
 ,""
 ,""
 ,""

]
, "Date"
: ""

, "Evaluation Start Time"
: ""

, "Evaluation End Time"
: ""

, "Paid Absence Time"
: ""

, "Unpaid Absence Time"
: ""

, "Absence"
: ""

, "Break Time Net"
: ""

, "Break Deduction Time"
: ""

, "Feast Time"
: ""

, "Break Time"
: ""

, "Sickness Time"
: ""

, "Working Time Correction"
: ""

, "Actual Working Time"
: ""

, "Target Working Time"
: ""

, "System Remark"
: ""

, "Remark"
: ""

, "Is Cleared"
: ""

, "Cleared in"
: ""

, "Working time, Working times"
: [
  ""
 ,""
 ,""
 ,""

]
, "Quick search"
: ""

, "Extra free times"
: ""

, "Free Time, Free Times"
: [
  "Urlop"
 ,"Urlopy"
 ,"Urlopy"
 ,"Urlopy"

]
, "Account"
: "Konto"

, "First Day"
: ""

, "Last Day"
: ""

, "Days Count"
: ""

, "Free Days"
: ""

, "Private Information"
: ""

, "Is employed"
: ""

, "Number"
: "Numer"

, "Badge Id"
: ""

, "Germany"
: ""

, "Locality"
: "Miejscowość"

, "Postalcode"
: "Kod pocztowy"

, "Region"
: "Region"

, "Street"
: "Ulica"

, "Street 2"
: ""

, "E-Mail"
: "E-mail"

, "Telephone Number"
: "Numer telefonu stacjonarnego"

, "Cell Phone Number"
: "Numer telefonu komórkowego"

, "Last Name"
: "Nazwisko"

, "First Name"
: "Imię"

, "Employee name"
: "Nazwa pracownika"

, "Account Holder"
: "Właściciel konta"

, "Account Number"
: "Numer konta"

, "Bank Name"
: "Nazwa banku"

, "Code Number"
: "Kod"

, "Employment begin"
: "Początek zatrudnienia"

, "Employment end"
: "Koniec zatrudnienia"

, "Supervisor"
: "Przełożony"

, "Profession"
: "Zawód"

, "Position"
: ""

, "Contracts"
: ""

, "Cost Centers"
: ""

, "Free Day, Free Days"
: [
  "Wolny dzień"
 ,"wolne dni"
 ,"wolne dni"
 ,"wolne dni"

]
, "Break, Breaks"
: [
  ""
 ,""
 ,""
 ,""

]
, "Workingtime"
: ""

, "No contract could be found."
: "Nie znaleziono umowy"

, "Please create a contract for this employee!"
: "Proszę utworzyć umowę dla niniejszego pracownika!"

, "Negative Timespace"
: ""

, "The start date of the contract must be before the end date!"
: ""

, "Not allowed!"
: ""

, "It's only allowed to book remaining vacation days from years in the past!"
: ""

, "Contracts overlap"
: ""

, "The contracts must not overlap!"
: ""

, "No or no valid year given"
: ""

, "Please use a valid year!"
: ""

, "No current contract!"
: ""

, "A current contract could not be found!"
: ""

, "Contract not editable"
: ""

, "You are not allowed to change the record if a vacation has been booked already!"
: ""

, "No personal account found"
: ""

, "An existing personal account could not be found. Please create one!"
: ""

, "edit private employee data"
: "Edytuj prywatne dane pracownika"

, "Edit birthday, account data and other private information of employee records"
: "Edytuj urodziny, dane o koncie bankowym i inne, prywatne informacje pracownika"

, "Public Holiday Calendar"
: ""

, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
: ""

, "Public Holidays"
: ""

, "Badge ID"
: ""

, "Human Resources"
: ""

, "Extra free time"
: ""

, "Employee"
: "Pracownik"

, "CostCenter"
: "Centrum kosztów"

, "Cost Center"
: ""

, "Contract"
: "Umowa"

, "Personal account"
: ""

, "Daily Working Time Report"
: ""

, "Working time"
: ""

, "Free Time"
: "Urlop"

, "Free Day"
: "Wolny dzień"

, "Break"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
